
.. lcapy documentation master file, created by
   sphinx-quickstart on Mon Feb 17 17:08:01 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to lcapy's documentation!
====================================

Lcapy is a Python package for linear circuit analysis.  Lcapy uses
SymPy (symbolic Python) for symbolic analysis.  Lcapy can
semi-automate the drawing of schematics from a netlist, including
diodes and transistors.

.. image:: examples/schematics/lpf1-buffer-loaded2.png
   :width: 9cm

Contents:
=========

.. toctree::
   :maxdepth: 3

   install.rst
   tutorial.rst
   expressions.rst           
   circuits.rst
   networks.rst
   netlists.rst
   schematics.rst
   latex.rst                                        
   problems.rst                          
   internals.rst            
   api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

